@@ -1,6 +1,8 @@
-__version__ = "0.5.2"
+__version__ = "0.10.2"
 
 from .entity import BaseEntity
 from .filter import Attribute, Filter
+from .label import label
+from .memory import MemoryVisitor
 from .sqlalchemy import SQLAlchemyVisitor
 from .visitor import BaseVisitor
